<?php 
if (!defined('BASEPATH'))
    exit('No direct script access allowed');

class RafahPort extends CI_Controller {

    public function __construct() {
        parent::__construct();
        $this->load->model('rafah_port_model');
        $this->user_sso->validate_session();

        if (!$this->user_sso->is_valid_session()) {
            $userSSO_ID = $this->user_sso->getUserID();
            $this->user_sso->set_user_session($userSSO_ID);
        }
    }

    public function index()
    {   
        $this->manageShiftInfo();
    }

    public function shiftInfo(){
        if (!$this->user_sso->is_allowed_function('284')) {
            redirect('/messages/disply_msg/1020/');
            return;
        } 
        $data['view_title'] = 'إدخال بيانات وردية معبر رفح';
        $data['username'] = $this->user_sso->getUserName();
        $data['titles'] = $this->rafah_port_model->getJobTitlesList(); 
        $this->load->view('includes/header.php', $data);
        $this->load->view('includes/sidebar', $data);
        $this->load->view('rafah/shiftInfo.php', $data);
        $this->load->view('includes/footer.php', $data);   
    }

    public function getRafahPortWorkersByTerm(){
        $term = $this->input->post('term'); 
        echo(json_encode($this->rafah_port_model->getRafahPortWorkersByTerm($term))); exit(); 
    }

    public function addRafahShiftInfo(){
        if (!$this->user_sso->is_allowed_function('284')) {
            echo(json_encode(array('SUCCESS' => 0, 'MSG' => 'لست مخول للقيام بهذه العملية')));  
            return;
        } 
        $info = array(
            'SHIFT_DATE' => $this->input->post('SHIFT_DATE'),
            'START_TIME' => $this->input->post('START_TIME'),
            'END_TIME' => $this->input->post('END_TIME'),
            'WORK_DIRECTION' => $this->input->post('WORK_DIRECTION'),
            'INSERT_USER' => $this->user_sso->getUserID()
        );
        $workersDetails = json_decode($this->input->post('workerDetails'));
        $result = array(); 
        if (count($workersDetails) > 0) {
            $masterResult = $this->rafah_port_model->addRafahShiftInfo($info);
            $shiftSerial = $masterResult['SERIAL'];
            if ($shiftSerial > 0) {
                for ($i = 0; $i < count($workersDetails); $i++) { 
                    $item = json_decode($workersDetails[$i]);
                    $workerResult = $this->rafah_port_model->addRafahSiftWorker(array(
                        'SHIFT_SR' => $shiftSerial,
                        'WORKER_ID' => $item->EMPLOYEE_ID,
                        'JOB_TITLE' => $item->EMP_JOP
                    ));
                    $result = $workerResult; 
                }
            } else {
                $result = array('SUCCESS' => 0, 'MSG' => $masterResult['MSG']);
            }
        } else {
            $result = array('SUCCESS' => 0, 'MSG' => 'بيانات العاملين في الوردية غير متوفرة');
        }
        echo json_encode($result);
    }

    public function manageShiftInfo(){
        if (!$this->user_sso->is_allowed_function('283')) {
            redirect('/messages/disply_msg/1020/');
            return;
        } 
        $data['view_title'] = 'ادارة بيانات ورديات معبر رفح للبترول';
        $data['username'] = $this->user_sso->getUserName();
        $data['titles'] = $this->rafah_port_model->getJobTitlesList(); 
        $this->load->view('includes/header.php', $data);
        $this->load->view('includes/sidebar', $data);
        $this->load->view('rafah/manageShiftInfo.php', $data);
        $this->load->view('includes/footer.php', $data); 
    }

    public function getWorkShiftsInfo(){
        /*
        if (!$this->user_sso->is_allowed_function('283')) {
            redirect('/messages/disply_msg/1020/');
            return;
        } */
        $data = array(
            'SERIAL' => null,
            'WORK_DIRECTION' => $this->input->post('WORK_DIRECTION'),
            'START_DATE' => $this->input->post('START_DATE'),
            'END_DATE' => $this->input->post('END_DATE'),
        );
        echo(json_encode($this->rafah_port_model->getWorkShiftsInfo($data))); exit(); 
    }

    public function deleteShiftInfo(){
        if (!$this->user_sso->is_allowed_function('285')) {
            echo(json_encode(array('SUCCESS' => 0, 'MSG' => 'لست مخول للقيام بهذه العملية'))); 
            return;
        } 
        $data = array(
            'SERIAL' => $this->input->post('SHIFT_SR'),
        );
        echo(json_encode($this->rafah_port_model->deleteShiftInfo($data))); exit(); 
    }

    public function registerTanksGaugesForm(){
        if (!$this->user_sso->is_allowed_function('1')) {
            redirect('/messages/disply_msg/1020/');
            return;
        } 
        $data['view_title'] = 'نموذج تسجيل قياسات خزانات الوقود - معبر رفح';
        $data['username'] = $this->user_sso->getUserName();
        $data['tanks'] = $this->rafah_port_model->getRafahTanksList(); 
        $this->load->view('includes/header.php', $data);
        $this->load->view('includes/sidebar', $data);
        $this->load->view('rafah/tanksGaugesForm.php', $data);
        $this->load->view('includes/footer.php', $data); 
    }

    public function saveTankGaugesData(){
        $gaugesDetails = json_decode($this->input->post('GAUGES_DATA'));
        $result = array(); 
        if (count($gaugesDetails) > 0) {
            $savedRecs = 0; 
            foreach ($gaugesDetails as $gauges) {
                $gauge = json_decode($gauges); 
                $info = array(
                    'AT_WORK' => $this->input->post('AT_WORK'),
                    'GAUGE_DATE' => $this->input->post('GAUGE_DATE'),
                    'GAUGE_TIME' => $this->input->post('GAUGE_TIME'),
                    'SHIFT_SR' => $this->input->post('SHIFT_SR'),
                    'TANK_SR' => $gauge->TANK_SR, 
                    'TANK_VALUE' => $gauge->TANK_VALUE, 
                    'TANK_PRODUCT' => $gauge->TANK_PRODUCT, 
                    'TANK_NOTES' => $gauge->TANK_NOTES , 
                    'INSERT_USER' => $this->user_sso->getUserID()
                ); 
                $success = $this->rafah_port_model->addTankGaugesData($info); 
                if($success) $savedRecs += 1 ;
            }
            $result = array('SUCCESS' => $savedRecs, 'MSG' => 'تمت تسجيل قياسات '. $savedRecs .' مخزن');
        } else {
            $result = array('SUCCESS' => 0, 'MSG' => 'بيانات القياسات غير متوفرة');
        }
        echo json_encode($result);
    }

    public function getTanksGaugesData(){
        $info = array(
            'GAUGE_START' => $this->input->post('GAUGE_START'), 
            'GAUGE_END' => $this->input->post('GAUGE_END'), 
            'AT_DAY_TIME' => $this->input->post('AT_DAY_TIME'), 
            'SHIFT_SR' => $this->input->post('SHIFT_SR'), 
            'TANK_SR' => $this->input->post('TANK_SR'), 
            'PRODUCT_SR' => $this->input->post('PRODUCT_SR'), 
        );
        echo(json_encode($this->rafah_port_model->getTanksGaugesData($info))); exit();
    }

    public function getLastGaugesData(){
        $info = array(
            'GDAY' => $this->input->post('GDAY') 
        );
        echo(json_encode($this->rafah_port_model->getPreviousDayTanksGauges($info))); exit();
    }

    public function TanksGaugesMaster(){
        if (!$this->user_sso->is_allowed_function('1')) {
            redirect('/messages/disply_msg/1020/');
            return;
        } 
        $data['view_title'] = 'ادارة قياسات خزانات الوقود - معبر رفح';
        $data['username'] = $this->user_sso->getUserName();
        $data['tanks'] = $this->rafah_port_model->getRafahTanksList(); 
        $this->load->view('includes/header.php', $data);
        $this->load->view('includes/sidebar', $data);
        $this->load->view('rafah/tanksGaugesMaster.php', $data);
        $this->load->view('includes/footer.php', $data); 
    }
}